Crate cw_dex_osmosis

Crate cw_dex_osmosis 

Contains cw-dex Pool and Staking implementations for Osmosis

Re-exports

pub use osmosis_std;
pub use cw_dex;

Structs

OsmosisPool
Struct for interacting with Osmosis v1beta1 balancer pools. If pool_id maps to another type of pool this will fail.
OsmosisStaking
Implementation of locked staking on osmosis. Using the Staking trait. lockup_duration is the duration of the lockup period in nano seconds.
OsmosisSuperfluidStaking
Implementation of superfluid staking for osmosis.

Constants

OSMOSIS_LOCK_TOKENS_REPLY_ID
Reply ID for locking tokens
OSMOSIS_UNLOCK_TOKENS_REPLY_ID
Reply ID for unlocking tokens