Contains cw-dex Pool and Staking implementations for Osmosis
Re-exports
pub use osmosis_std;pub use cw_dex;
Structs
- Osmosis
Pool - Struct for interacting with Osmosis v1beta1 balancer pools. If
pool_idmaps to another type of pool this will fail. - Osmosis
Staking - Implementation of locked staking on osmosis. Using the Staking trait.
lockup_durationis the duration of the lockup period in nano seconds. - Osmosis
Superfluid Staking - Implementation of superfluid staking for osmosis.
Constants
- OSMOSIS_
LOCK_ TOKENS_ REPLY_ ID - Reply ID for locking tokens
- OSMOSIS_
UNLOCK_ TOKENS_ REPLY_ ID - Reply ID for unlocking tokens